@@ -69,7 +69,7 @@ use Scalar::Util ();
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '1.03';
+	$VERSION = '1.04';
 }
 
 
@@ -138,7 +138,7 @@ For other issues, contact the author.
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>cpan@ali.asE<gt>, L<http://ali.as/>
+Adam Kennedy E<lt>adamk@cpan.orgE<gt>, L<http://ali.as/>
 
 =head1 SEE ALSO
 
@@ -146,7 +146,7 @@ L<Class::Adapter::Clear>, L<Class::Adapter::Builder>, L<Class::Decorator>
 
 =head1 COPYRIGHT
 
-Copyright 2005 Adam Kennedy. All rights reserved.
+Copyright 2005 Adam Kennedy.
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
 
